package com.mortals.xhx.module.api.model;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.util.Date;
import java.util.Map;

/**
 *
 *  事件日志查询返回结果
 * @author luoshichao
 * @Description
 * @date 2021/3/10 11:12
 */
@ApiModel
@Data
public class AssetEventLogInfo{

    /** 资产日志ID */
    @ApiModelProperty(value = "id", required = true, example = "1")
    private Long id;

    /** 资产码，全局唯一 */
    @ApiModelProperty(value = "资产码", required = true, example = "1111912400000209")
    private String assetNum;

    /** 事件编号 */
    @ApiModelProperty(value = "事件编号", required = true, example = "101")
    private String eventCode;

    /** 事件经手人，登录名 */
    @ApiModelProperty(value = "事件经手人，登录名", required = true, example = "admin")
    private String eventUser;

    /** 事件关联人，登录名,多个以逗号分隔 */
    @ApiModelProperty(value = "事件关联人，登录名,多个以逗号分隔", required = true, example = "admin,zhangsan")
    private String eventAfterUser;

    /** 事件发生地，自动采集到的地址 */
    @ApiModelProperty(value = "事件发生地，自动采集到的地址", required = true, example = "成都市环球中心N1")
    private String eventAddress;

    /** 事件关联图像，图片或视频地址，多个以逗号分隔 */
    @ApiModelProperty(value = "事件关联图像，图片或视频地址，多个以逗号分隔", required = false, example = "http://image.test.com/11.jpg")
    private String eventImgUrl;

    /** 事件发生时间 */
    @ApiModelProperty(value = "事件发生开始时间", required = true, example = "2021-02-24 10:10:10")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date eventStartTime;
    /** 事件发生时间 */
    @ApiModelProperty(value = "事件发生时间", required = true, example = "2021-02-24 10:10:10")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date eventTime;

    /** 备注 */
    @ApiModelProperty(value = "备注", required = false, example = "")
    private String remark;


    /** 事件扩展信息，json串，基于事件扩展属性产生, 参看mortals.xhx.table_ext_field表 */
    @ApiModelProperty(value = "事件扩展信息，key-value，基于事件扩展属性产生", required = false, example = "")
    private Map<String, Object> eventExtInfo;

    @ApiModelProperty(value = "回显信息", required = false)
    private String showInfo;
}
